summaryrefslogtreecommitdiffstats
path: root/lib/kofficecore/KoPictureShared.h
diff options
context:
space:
mode:
authortpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-06-25 05:28:35 +0000
committertpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-06-25 05:28:35 +0000
commitf008adb5a77e094eaf6abf3fc0f36958e66896a5 (patch)
tree8e9244c4d4957c36be81e15b566b4aa5ea26c982 /lib/kofficecore/KoPictureShared.h
parent1210f27b660efb7b37ff43ec68763e85a403471f (diff)
downloadkoffice-f008adb5a77e094eaf6abf3fc0f36958e66896a5.tar.gz
koffice-f008adb5a77e094eaf6abf3fc0f36958e66896a5.zip
TQt4 port koffice
This should enable compilation under both Qt3 and Qt4; fixes for any missed components will be forthcoming git-svn-id: svn://anonsvn.kde.org/home/kde/branches/trinity/applications/koffice@1238284 283d02a7-25f6-0310-bc7c-ecb5cbfe19da
Diffstat (limited to 'lib/kofficecore/KoPictureShared.h')
-rw-r--r--lib/kofficecore/KoPictureShared.h76
1 files changed, 38 insertions, 38 deletions
diff --git a/lib/kofficecore/KoPictureShared.h b/lib/kofficecore/KoPictureShared.h
index da286368..f90c91e4 100644
--- a/lib/kofficecore/KoPictureShared.h
+++ b/lib/kofficecore/KoPictureShared.h
@@ -20,16 +20,16 @@
#ifndef __koPictureShared_h__
#define __koPictureShared_h__
-#include <qshared.h>
-#include <qstring.h>
-#include <qiodevice.h>
-#include <qpixmap.h>
+#include <tqshared.h>
+#include <tqstring.h>
+#include <tqiodevice.h>
+#include <tqpixmap.h>
#include "KoPictureKey.h"
class KoXmlWriter;
-class QPainter;
-class QSize;
+class TQPainter;
+class TQSize;
class KURL;
@@ -39,9 +39,9 @@ class KoPictureBase;
* @internal
* KoPictureShared is the class that contains the shared part for KoPicture
*
* @warning As with all QShared objects, the sharing is neither automatic nor transparent!
*/
-class KoPictureShared : public QShared
+class KoPictureShared : public TQShared
{
public:
/**
@@ -82,29 +82,29 @@ public:
*
* The parameters @p width, @p height define the desired size for the picture
*
* The other parameters are very similar to QPainter::drawPixmap :
* (@p x, @p y) define the position in the painter,
* (@p sx, @p sy) specify the top-left point in pixmap that is to be drawn. The default is (0, 0).
* (@p sw, @p sh) specify the size of the pixmap that is to be drawn. The default, (-1, -1), means all the way to the bottom
* right of the pixmap.
*/
- void draw(QPainter& painter, int x, int y, int width, int height, int sx = 0, int sy = 0, int sw = -1, int sh = -1, bool fastMode = false);
+ void draw(TQPainter& painter, int x, int y, int width, int height, int sx = 0, int sy = 0, int sw = -1, int sh = -1, bool fastMode = false);
/**
* Create a dragobject containing this picture.
* @param dragSource must be 0 when copying to the clipboard
* @return 0L if the picture is null!
*/
- QDragObject* dragObject( QWidget *dragSource = 0L, const char *name = 0L );
+ TQDragObject* dragObject( TQWidget *dragSource = 0L, const char *name = 0L );
- bool load(QIODevice* io, const QString& extension);
- bool loadFromBase64( const QCString& str );
+ bool load(TQIODevice* io, const TQString& extension);
+ bool loadFromBase64( const TQCString& str );
/**
* Save picture into a QIODevice
* @param io QIODevice used for saving
*/
- bool save(QIODevice* io) const;
+ bool save(TQIODevice* io) const;
/**
* OASIS FlatXML support:
@@ -112,18 +112,18 @@ public:
*/
bool saveAsBase64( KoXmlWriter& writer ) const;
- void setExtension(const QString& extension);
+ void setExtension(const TQString& extension);
- QString getExtension(void) const;
+ TQString getExtension(void) const;
- QSize getOriginalSize(void) const;
+ TQSize getOriginalSize(void) const;
/**
* Clear and set the mode of this KoPictureShared
*
* @param newMode file extension (like "png") giving the wanted mode
*/
- void clearAndSetMode(const QString& newMode);
+ void clearAndSetMode(const TQString& newMode);
/**
* Reset the KoPictureShared (but not the key!)
@@ -135,35 +135,35 @@ public:
*
* @param fileName the name of the file to load
*/
- bool loadFromFile(const QString& fileName);
+ bool loadFromFile(const TQString& fileName);
/**
* Load a potentially broken XPM file (for KPresenter)
*/
- bool loadXpm(QIODevice* io);
+ bool loadXpm(TQIODevice* io);
/**
* @deprecated
* Returns a QPixmap from an image
*
* @param size the wanted size for the QPixmap
*/
- QPixmap generatePixmap(const QSize& size, bool smoothScale = false);
+ TQPixmap generatePixmap(const TQSize& size, bool smoothScale = false);
- QString getMimeType(void) const;
+ TQString getMimeType(void) const;
/**
- * Generate a QImage
+ * Generate a TQImage
*
* (always in slow mode)
*
* @param size the wanted size for the QImage
*/
- QImage generateImage(const QSize& size);
+ TQImage generateImage(const TQSize& size);
bool hasAlphaBuffer() const;
void setAlphaBuffer(bool enable);
- QImage createAlphaMask(int conversion_flags = 0) const;
+ TQImage createAlphaMask(int conversion_flags = 0) const;
/**
* Clear any cache
@@ -173,25 +173,25 @@ public:
*/
void clearCache(void);
- QString uniquePictureId() const;
+ TQString uniquePictureId() const;
void assignPictureId( uint _id);
protected:
/**
* @internal
* Load a WMF file
- * \note In %KOffice 1.1, a .wmf file was a QPicture file
+ * \note In %KOffice 1.1, a .wmf file was a TQPicture file
*/
- bool loadWmf(QIODevice* io);
+ bool loadWmf(TQIODevice* io);
/**
* @internal
* Loads a temporary file, probably from a downloaded file
*/
- bool loadTmp(QIODevice* io);
+ bool loadTmp(TQIODevice* io);
/// Find type of image, create base accordingly, and load data
- bool identifyAndLoad( QByteArray data );
+ bool identifyAndLoad( TQByteArray data );
/**
* @internal
@@ -199,15 +199,15 @@ protected:
*
* @warning risk of endless recurision, be careful when it is called from @see load
*
* @param io QIODevice of the compressed file/strea,
* @param mimeType mimetype of the (de-)compressor
* @param extension extension of the uncompressed file
*/
- bool loadCompressed( QIODevice* io, const QString& mimeType, const QString& extension );
+ bool loadCompressed( TQIODevice* io, const TQString& mimeType, const TQString& extension );
protected:
KoPictureBase* m_base;
- QString m_extension;
+ TQString m_extension;
uint m_pictureId;
};
@@ -39,9 +39,9 @@ class KoPictureBase;
* KoPictureShared is the class that contains the shared part for KoPicture
*
- * @warning As with all QShared objects, the sharing is neither automatic nor transparent!
+ * @warning As with all TQShared objects, the sharing is neither automatic nor transparent!
*/
@@ -82,29 +82,29 @@ public:
* The parameters @p width, @p height define the desired size for the picture
*
- * The other parameters are very similar to QPainter::drawPixmap :
+ * The other parameters are very similar to TQPainter::drawPixmap :
* (@p x, @p y) define the position in the painter,
* (@p sx, @p sy) specify the top-left point in pixmap that is to be drawn. The default is (0, 0).
@@ -82,29 +82,29 @@ public:
/**
- * Save picture into a QIODevice
- * @param io QIODevice used for saving
+ * Save picture into a TQIODevice
+ * @param io TQIODevice used for saving
*/
@@ -135,35 +135,35 @@ public:
/**
* @deprecated
- * Returns a QPixmap from an image
+ * Returns a TQPixmap from an image
*
@@ -135,35 +135,35 @@ public:
*
- * @param size the wanted size for the QPixmap
+ * @param size the wanted size for the TQPixmap
*/
@@ -135,35 +135,35 @@ public:
* (always in slow mode)
*
- * @param size the wanted size for the QImage
+ * @param size the wanted size for the TQImage
*/
@@ -199,15 +199,15 @@ protected:
* @warning risk of endless recurision, be careful when it is called from @see load
*
- * @param io QIODevice of the compressed file/strea,
+ * @param io TQIODevice of the compressed file/strea,
* @param mimeType mimetype of the (de-)compressor
* @param extension extension of the uncompressed file